@@ -1,3 +1,4 @@
+import logging
 import random
 import math
 
@@ -6,10 +7,13 @@ from chase.model.wolf import Wolf
 
 
 def is_coordinate_empty(coX: float, coY: float, sheep_list: list, wolf: Wolf):
+    logging.debug("Checking if the coordinates are busy")
     if (coX is wolf.coX) and (coY is wolf.coY):
+        logging.warning("the sheep is trying to enter the coordinates of the wolf")
         return False
     for entity in sheep_list:
         if (coX is entity.coX) and (coY is entity.coY) and entity.isAlive:
+            logging.info("Coordinates are in use")
             return False
     return True
 
